@@ -530,4 +530,8 @@
   'group.id',
 ],
 
+'config.rdf.tmpl' => [
+  'escaped_urlbase',
+],
+
 );
